aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--modules/cj-cache-lib.el (renamed from modules/cj-cache.el)6
-rw-r--r--modules/org-agenda-config.el2
-rw-r--r--modules/org-refile-config.el2
-rw-r--r--tests/test-cj-cache.el2
4 files changed, 6 insertions, 6 deletions
diff --git a/modules/org-agenda-config.el b/modules/org-agenda-config.el
index 049ece7b..6c60e8dd 100644
--- a/modules/org-agenda-config.el
+++ b/modules/org-agenda-config.el
@@ -44,7 +44,7 @@
;;; Code:
(require 'user-constants)
(require 'system-lib)
-(require 'cj-cache)
+(require 'cj-cache-lib)
;; Load debug functions if enabled
(when (or (eq cj/debug-modules t)
diff --git a/modules/org-refile-config.el b/modules/org-refile-config.el
index 8d989e4b..63343e9f 100644
--- a/modules/org-refile-config.el
+++ b/modules/org-refile-config.el
@@ -14,7 +14,7 @@
;;; Code:
(require 'system-lib)
-(require 'cj-cache)
+(require 'cj-cache-lib)
;; ----------------------------- Org Refile Targets ----------------------------
;; sets refile targets
diff --git a/tests/test-cj-cache.el b/tests/test-cj-cache.el
index 76315acd..68f2bf0e 100644
--- a/tests/test-cj-cache.el
+++ b/tests/test-cj-cache.el
@@ -12,7 +12,7 @@
(require 'cl-lib)
(add-to-list 'load-path (expand-file-name "modules" user-emacs-directory))
-(require 'cj-cache)
+(require 'cj-cache-lib)
;;; cj/cache-make
diff --git a/modules/cj-cache.el b/modules/cj-cache-lib.el
index b7d048c9..9aad51a3 100644
--- a/modules/cj-cache.el
+++ b/modules/cj-cache-lib.el
@@ -1,4 +1,4 @@
;;; cj-cache.el --- Generic TTL cache with build-guard -*- lexical-binding: t; -*-
;; Author: Craig Jennings <c@cjennings.net>
@@ -91,5 +91,5 @@ rethrown after ON-BUILD-ERROR fires."
(signal (car err) (cdr err))))
(plist-put cache :building nil)))))
-(provide 'cj-cache)
-;;; cj-cache.el ends here
+(provide 'cj-cache-lib)
+;;; cj-cache-lib.el ends here
@@ -1,4 +1,4 @@
-;;; cj-cache.el --- Generic TTL cache with build-guard -*- lexical-binding: t; -*-
+;;; cj-cache-lib.el --- Generic TTL cache with build-guard -*- lexical-binding: t; -*-
;; Author: Craig Jennings <c@cjennings.net>